package com.persagy.apm.diagnose.service;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.persagy.apm.diagnose.feign.AlarmResult;
import com.persagy.apm.diagnose.feign.client.AlarmServiceClient;
import com.persagy.apm.diagnose.service.dto.CalculateMethodDTO;
import com.persagy.apm.diagnose.service.dto.MonitorIndicatorConfigDTO;
import com.persagy.apm.diagnose.utils.AlarmResultUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * OriginalPresent采集当前数据查询
 *
 * @author strootman
 * @version 1.0
 * @date 2018年8月17日
 */
@Service
public class EnergyAlarmServiceImpl {

    @Autowired
    AlarmServiceClient alarmServiceClient;

    /**
     * @title queryMonitorIndicatorConfigDTOList
     * @description 查询监控指标配置
     * @author leifeng
     * @param: projectId
     * @updateTime 2021/9/23 20:29
     * @return: java.util.List<com.persagy.apm.diagnose.service.dto.MonitorIndicatorConfigDTO>
     * @throws
     */
    public List<MonitorIndicatorConfigDTO> queryMonitorIndicatorConfigDTOList(String projectId) throws Exception {
        MonitorIndicatorConfigDTO monitorIndicatorConfigDTO = MonitorIndicatorConfigDTO.builder().build();
        monitorIndicatorConfigDTO.setProjectId(projectId);
        AlarmResult<JSONObject> result = alarmServiceClient.query(monitorIndicatorConfigDTO);
        return AlarmResultUtil.getRecords(result,MonitorIndicatorConfigDTO.class);
    }


    /**
     * @title queryCalculateMethods
     * @description 查询所有计算公式,key为公式id
     * @author leifeng
     * @updateTime 2021/9/23 20:29
     * @return: java.util.Map<java.lang.String,com.persagy.apm.diagnose.service.dto.CalculateMethodDTO>
     * @throws
     */
    public Map<String, CalculateMethodDTO> queryCalculateMethods() throws Exception {
        AlarmResult<JSONObject> result = alarmServiceClient.queryCalculateMethods(CalculateMethodDTO.builder().build());
        List<CalculateMethodDTO> records = AlarmResultUtil.getRecords(result, CalculateMethodDTO.class);
        return records.stream().collect(Collectors.toMap(CalculateMethodDTO::getId, Function.identity(), (key1, key2) -> key2));
    }


}
